pub enum RenameTargetMode {
Overwrite,
Create,
}Expand description
Configure preconditions for the target of rename operation.
Note though that the source location may or not be deleted at the same time in an atomic operation. There is currently NO flag to control the atomicity of “delete source at the same time as creating the target”.
Variants
Overwrite
Perform a write operation on the target, overwriting any object present at the provided path.
Create
Perform an atomic write operation of the target, returning Error::AlreadyExists if an
object already exists at the provided path.