GetResult

Struct GetResult 

pub struct GetResult {
    pub payload: GetResultPayload,
    pub meta: ObjectMeta,
    pub range: Range<u64>,
    pub attributes: Attributes,
    pub extensions: Extensions,
}
Result for a get request

Fields

payload: GetResultPayloadmeta: ObjectMeta

The ObjectMeta for this object

range: Range<u64>

The range of bytes returned by this request

Note this is not usize as object_store supports 32-bit architectures such as WASM

attributes: Attributes

Additional object attributes

extensions: Extensions

Implementation-specific extensions. Intended for use by ObjectStore implementations that need to return context-specific information (like cache status) from trait methods.

HTTP-backed stores in this crate populate this with the extensions of the HTTP response, allowing custom HTTP middleware to propagate information to callers.

Implementations

Source

impl GetResult

pub async fn bytes(self) -> Result<Bytes>

Collects the data into a Bytes

pub fn into_stream(self) -> BoxStream<'static, Result<Bytes>>

Converts this into a byte stream

If the self.kind is [GetResultPayload::File] will perform chunked reads of the file, otherwise will return the GetResultPayload::Stream.

Tokio Compatibility

Tokio discourages performing blocking IO on a tokio worker thread, however, no major operating systems have stable async file APIs. Therefore if called from a tokio context, this will use tokio::runtime::Handle::spawn_blocking to dispatch IO to a blocking thread pool, much like tokio::fs does under-the-hood.

If not called from a tokio context, this will perform IO on the current thread with no additional complexity or overheads