pub struct ListResult {
pub common_prefixes: Vec<Path>,
pub objects: Vec<ObjectMeta>,
pub extensions: Extensions,
}Expand description
Result of a list call that includes objects, prefixes (directories) and a token for the next set of results. Individual result sets may be limited to 1,000 objects based on the underlying object storage’s limitations.
Fields
common_prefixes: Vec<Path>Prefixes that are common (like directories)
objects: Vec<ObjectMeta>Object metadata for the listing
extensions: ExtensionsImplementation-specific extensions. Intended for use by ObjectStore implementations
that need to return context-specific information (like cache status) from trait methods.
HTTP-backed stores in this crate populate this with the extensions of the HTTP response, allowing custom HTTP middleware to propagate information to callers. Where a result is assembled from multiple paginated requests, the extensions of each response are merged, with those of later responses taking precedence.